@@ -9,13 +9,13 @@ from omotes_sdk.internal.common.config import (
 
 @dataclass
 class WorkerConfig:
-    rabbitmq: RabbitMQConfig
+    rabbitmq_config: RabbitMQConfig
     task_result_queue_name: str
     task_progress_queue_name: str
     log_level: str
 
     def __init__(self):
-        self.rabbitmq = EnvRabbitMQConfig()
+        self.rabbitmq_config = EnvRabbitMQConfig()
         self.task_result_queue_name = os.environ.get(
             "TASK_RESULT_QUEUE_NAME", "omotes_task_result_events"
         )
